# $URL: /local/member/autrijus/Parse-AFP//lib/Parse/AFP/Triplet/MF.pm $ $Author: autrijus $
# $Rev: 3917 $ $Date: 2004-02-17T07:03:18.734947Z $

package Parse::AFP::Triplet::MF;
use base 'Parse::AFP::Triplet';

use constant SUBFORMAT => (
    Data => 'a*',    # not yet parsed!
);

1;
