# $URL: /local/member/autrijus/Parse-AFP//lib/Parse/AFP/PTX/TRN.pm $ $Author: autrijus $
# $Rev: 3918 $ $Date: 2004-02-17T10:05:07.533350Z $

package Parse::AFP::PTX::TRN;
use base 'Parse::AFP::PTX::ControlSequence';

use constant SUBFORMAT => (
    Data	=> 'a*',
);

1;
