# $URL: /local/member/autrijus/Parse-AFP//lib/Parse/AFP/PTX/SBI.pm $ $Author: autrijus $
# $Rev: 3917 $ $Date: 2004-02-17T07:03:18.734947Z $

package Parse::AFP::PTX::SBI;
use base 'Parse::AFP::PTX::ControlSequence';

use constant SUBFORMAT => (
    Data	=> 'n',
);

1;
